pub fn check_elbow(elbow: &[f64; 2]) -> FrankaResult<()>Expand description
Checks that the elbow vector is finite and that the elbow configuration is valid.
Port of franka::checkElbow.
pub fn check_elbow(elbow: &[f64; 2]) -> FrankaResult<()>Checks that the elbow vector is finite and that the elbow configuration is valid.
Port of franka::checkElbow.