pub fn check_finite(values: &[f64]) -> FrankaResult<()>Expand description
Checks that all elements of the array have a finite value.
Port of franka::checkFinite.
pub fn check_finite(values: &[f64]) -> FrankaResult<()>Checks that all elements of the array have a finite value.
Port of franka::checkFinite.