pub fn check_matrix(transform: &[f64; 16]) -> FrankaResult<()>Expand description
Checks that the transformation matrix is finite and a homogeneous transformation.
Port of franka::checkMatrix.
pub fn check_matrix(transform: &[f64; 16]) -> FrankaResult<()>Checks that the transformation matrix is finite and a homogeneous transformation.
Port of franka::checkMatrix.