pub fn motion_finished<T: Finishable>(command: T) -> TExpand description
Helper method to indicate that a motion should stop after processing the given command.
Port of franka::MotionFinished.
pub fn motion_finished<T: Finishable>(command: T) -> THelper method to indicate that a motion should stop after processing the given command.
Port of franka::MotionFinished.