pub struct CartesianVelocities {
pub O_dP_EE: [f64; 6],
pub elbow: [f64; 2],
pub has_elbow: bool,
pub motion_finished: bool,
}Expand description
Stores values for Cartesian velocity motion generation.
Port of franka::CartesianVelocities.
Fields
O_dP_EE: [f64; 6]Cartesian velocity with respect to the base frame O: (dx, dy, dz) in [m/s] and
(omega_x, omega_y, omega_z) in [rad/s].
elbow: [f64; 2]Elbow configuration, see CartesianPose::elbow.
has_elbow: boolWhether there is a stored elbow configuration, see CartesianPose::has_elbow.
motion_finished: boolDetermines whether to finish a currently running motion.
Implementations
Sourceimpl CartesianVelocities
impl CartesianVelocities
Sourcepub fn new(O_dP_EE: [f64; 6]) -> Self
pub fn new(O_dP_EE: [f64; 6]) -> Self
Creates a new CartesianVelocities without an elbow configuration.
Sourcepub fn with_elbow(O_dP_EE: [f64; 6], elbow: [f64; 2]) -> Self
pub fn with_elbow(O_dP_EE: [f64; 6], elbow: [f64; 2]) -> Self
Creates a new CartesianVelocities with an elbow configuration.
Sourcepub fn validate(&self) -> FrankaResult<()>
pub fn validate(&self) -> FrankaResult<()>
Validates the command like libfranka’s control_loop.cpp does before sending it
(checkFinite(command.O_dP_EE_c) and, if an elbow is set, checkElbow(command.elbow_c)).