pub struct Record {
pub state: RobotState,
pub command: Option<RobotCommandLog>,
}Expand description
One entry of the control log attached to a ControlException (mirrors franka::Record).
With the serde feature a Vec<Record> is what a control log looks like on disk.
Fields
state: RobotStateThe robot state received in this cycle.
command: Option<RobotCommandLog>The command sent in this cycle, or None when the cycle sent nothing.