Errors

Struct Errors 

pub struct Errors(pub [bool; 41]);
Set of robot error flags (mirrors franka::Errors).

With the serde feature it serialises as the list of the set flags’ names in wire order (["joint_reflex", "cartesian_reflex"], [] when empty) rather than as 41 booleans, and deserialising a name that is not in ERROR_NAMES is an error.

Tuple Fields

0: [bool; 41]

Implementations

Source

impl Errors

pub fn any(&self) -> bool

True if any flag is set (mirrors franka::Errors::operator bool).

pub fn names(&self) -> Vec<&'static str>

Names of the set flags, in wire order.

pub fn get(&self, name: &str) -> bool

Whether the flag with the given libfranka name is set. Unknown names are false.

pub fn index_of(name: &str) -> Option<usize>

Index of the flag with the given name.