pub fn connect_gripper(host: &str) -> FrankaResult<(Network, u16)>Expand description
Connects to a gripper and performs the Connect handshake, returning the session and the
server’s gripper protocol version.
pub fn connect_gripper(host: &str) -> FrankaResult<(Network, u16)>Connects to a gripper and performs the Connect handshake, returning the session and the
server’s gripper protocol version.