pub fn connect_robot(host: &str) -> FrankaResult<(Network, u16)>Expand description
Connects to a robot and performs the Connect handshake, returning the session and the
server’s FCI version.
pub fn connect_robot(host: &str) -> FrankaResult<(Network, u16)>Connects to a robot and performs the Connect handshake, returning the session and the
server’s FCI version.