compute_lower_limits_joint_velocity

Function compute_lower_limits_joint_velocity 

pub fn compute_lower_limits_joint_velocity(q: &[f64; 7]) -> [f64; 7]
Computes the minimum joint velocity based on joint position.

Port of the (deprecated) franka::computeLowerLimitsJointVelocity, which hardcodes the FR3 parameters. Prefer crate::joint_velocity_limits::JointVelocityLimitsConfig::lower_limits, which reads the same parameters from the robot’s URDF.