compute_upper_limits_joint_velocity

Function compute_upper_limits_joint_velocity 

pub fn compute_upper_limits_joint_velocity(q: &[f64; 7]) -> [f64; 7]
Computes the maximum joint velocity based on joint position.

Port of the (deprecated) franka::computeUpperLimitsJointVelocity, which hardcodes the FR3 parameters. Prefer crate::joint_velocity_limits::JointVelocityLimitsConfig::upper_limits, which reads the same parameters from the robot’s URDF.