limit_rate_joint_position

Function limit_rate_joint_position 

pub fn limit_rate_joint_position(
    upper_limits_velocity: f64,
    lower_limits_velocity: f64,
    max_acceleration: f64,
    max_jerk: f64,
    commanded_position: f64,
    last_commanded_position: f64,
    last_commanded_velocity: f64,
    last_commanded_acceleration: f64,
) -> f64
Limits the rate of a desired joint position considering the limits provided.

Port of the scalar franka::limitRate(double upper_limits_velocity, ..., double commanded_position, ...).

Unlike the C++ overload, this function does not check commanded_position for finiteness (the fixed Rust interface makes it infallible); limit_rate_joint_positions performs the check for the whole vector, exactly like the C++ vector overload does before delegating here.

Note

FCI filters must be deactivated to work properly.