limit_rate_joint_velocity

Function limit_rate_joint_velocity 

pub fn limit_rate_joint_velocity(
    upper_limits_velocity: f64,
    lower_limits_velocity: f64,
    max_acceleration: f64,
    max_jerk: f64,
    commanded_velocity: f64,
    last_commanded_velocity: f64,
    last_commanded_acceleration: f64,
) -> f64
Limits the rate of a desired joint velocity considering the limits provided.

Port of the scalar franka::limitRate(double upper_limits_velocity, ..., double commanded_velocity, ...).

Unlike the C++ overload, this function does not check commanded_velocity for finiteness (the fixed Rust interface makes it infallible); limit_rate_joint_velocities performs the check for the whole vector, exactly like the C++ vector overload does before delegating here.

Note

FCI filters must be deactivated to work properly.