ActiveMotionInput

Trait ActiveMotionInput 

pub trait ActiveMotionInput: MotionGenerator {
    // Required method
    fn create_motion_command(&self) -> FrankaResult<MotionGeneratorCommand>;
}
Motion command types that can drive an ActiveMotionGenerator.

Implemented for exactly the four franka::MotionGenerator command types; the method is the Rust equivalent of the Robot::Impl::createMotionCommand overload set, which validates the user’s values before they are put on the wire.

Required Methods

fn create_motion_command(&self) -> FrankaResult<MotionGeneratorCommand>

Validates the command and converts it into the wire motion command.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors