VirtualWallCuboid

Struct VirtualWallCuboid 

pub struct VirtualWallCuboid {
    pub id: i32,
    pub object_world_size: [f64; 3],
    pub p_frame: [f64; 16],
    pub active: bool,
}
Parameters of a cuboid used as a virtual wall (franka::VirtualWallCuboid, libfranka 0.9.2 include/franka/command_types.h).

Returned by crate::Robot::virtual_wall, which is FCI v5 only.

Fields

id: i32

ID of the virtual wall.

object_world_size: [f64; 3]

Corner point of the cuboid in the world frame, in [m].

p_frame: [f64; 16]

4x4 transformation matrix, column-major.

active: bool

true if this Cartesian limit is active.