pub fn combine_center_of_mass(
m_ee: f64,
F_x_Cee: &[f64; 3],
m_load: f64,
F_x_Cload: &[f64; 3],
) -> [f64; 3]Expand description
Combines the centres of mass of the end effector and the load.
Port of franka::combineCenterOfMass (src/load_calculations.cpp, libfranka 0.21.2): the
mass-weighted mean, or all zeros when the combined mass is not positive.