#[repr(u16)]pub enum GripperCommand {
Connect = 0,
Homing = 1,
Grasp = 2,
Move = 3,
Stop = 4,
}Expand description
Gripper command identifiers (research_interface::gripper::Command, uint16_t).
Variants
Connect = 0
Handshake that opens the session (kConnect).
Homing = 1
Homes the gripper and calibrates its maximum width (kHoming).
Grasp = 2
Grasps an object (kGrasp).
Move = 3
Moves the fingers to a width at a speed (kMove).
Stop = 4
Aborts the running gripper command (kStop).
Implementations